Default dark ThemeData built from AppColorSchemes.dark.
Use this when your app does not require brand-level customisation:
MaterialApp(
theme: LightTheme.build(),
darkTheme: DarkTheme.build(),
themeMode: ThemeMode.system,
)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited