AppBreakpoints class abstract final

Responsive breakpoint tokens.

Use isTablet with AppScale to get adaptive sizing values for the current screen width.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isTablet(double width) bool
Returns true when width is at or above the tablet breakpoint.

Constants

tablet → const double
Tablet / large-screen breakpoint for scaled-up UI elements.
wide → const double
Two-column layout breakpoint.