SurfaceLevel enum

Defines the elevation tier of an DsSurface container.

Maps directly to the Material 3 surface container roles: https://m3.material.io/styles/color/the-color-system/color-roles

Inheritance
Available extensions

Values

lowest → const SurfaceLevel

ColorScheme.surfaceContainerLowest — deepest recessed areas.

low → const SurfaceLevel

ColorScheme.surfaceContainerLow — card backgrounds, list tiles.

base → const SurfaceLevel

ColorScheme.surfaceContainer — navigation bars, sidebars.

high → const SurfaceLevel

ColorScheme.surfaceContainerHigh — dialogs, popovers.

highest → const SurfaceLevel

ColorScheme.surfaceContainerHighest — input fills, tooltips.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SurfaceLevel>
A constant List of the values in this enum, in order of their declaration.