8pt spacing system tokens.
Use these constants instead of arbitrary numeric literals for all padding, gap, and margin values in the UI. Widgets should always reference named tokens so spacing decisions are traceable and globally adjustable from a single location.
Padding(
padding: const EdgeInsets.all(AppSpacing.x2), // 16 px
child: ...,
)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- Button content padding — 24 px horizontal, 12 px vertical.
- cardPadding → const EdgeInsets
- Standard card inner padding — 16 px all sides.
- compactPadding → const EdgeInsets
- Compact inner padding — 12 px all sides.
- gap0_5 → const Widget
- gap1 → const Widget
- gap1_5 → const Widget
- gap2 → const Widget
- gap3 → const Widget
- gap4 → const Widget
- gap5 → const Widget
- gap6 → const Widget
- gapH0_5 → const Widget
- gapH1 → const Widget
- gapH1_5 → const Widget
- gapH2 → const Widget
- gapH3 → const Widget
- gapH4 → const Widget
- gapV0_5 → const Widget
- gapV1 → const Widget
- gapV1_5 → const Widget
- gapV2 → const Widget
- gapV3 → const Widget
- gapV4 → const Widget
- gapV5 → const Widget
- gapV6 → const Widget
- inputPadding → const EdgeInsets
- Input field content padding — 16 px horizontal, 12 px vertical.
- pagePadding → const EdgeInsets
- Horizontal page gutter — 16 px each side.
- screenPadding → const EdgeInsets
- Screen-level padding — 16 px all sides.
- x0_5 → const double
- x1 → const double
- x1_5 → const double
- x2 → const double
- x3 → const double
- x4 → const double
- x5 → const double
- x6 → const double